@@ -10,7 +10,18 @@ use overload '""' => sub {$_[0]->name}, fallback => 1;
 
 __PACKAGE__->load_components("PK::Auto", "Core");
 __PACKAGE__->table("tag");
-__PACKAGE__->add_columns("id", "name");
+__PACKAGE__->add_columns(
+    "id" => {
+    data_type => 'integer',
+    is_auto_increment => 1
+  },
+  'name' => {
+    data_type => 'varchar',
+    size      => 100,
+    is_nullable => 1,
+  },
+);
+    
 __PACKAGE__->set_primary_key("id");
 __PACKAGE__->has_many("dvdtags", "Dvdtag", { "foreign.tag" => "self.id" });
 __PACKAGE__->many_to_many('dvds', 'dvdtags' => 'dvd');
