@@ -9,7 +9,10 @@ use base 'DBIx::Class';
 
 __PACKAGE__->load_components("PK::Auto", "Core");
 __PACKAGE__->table("user_role");
-__PACKAGE__->add_columns("user", "role");
+__PACKAGE__->add_columns(
+    "user" => { data_type => 'integer' } , 
+    "role" => { data_type => 'integer' }
+);
 __PACKAGE__->set_primary_key("user", "role");
 __PACKAGE__->belongs_to("user", "User", { id => "user" });
 __PACKAGE__->belongs_to("role", "Role", { id => "role" });
